@@ -9,7 +9,7 @@ from nlp_utils_ch.utils.logger import log
 
 def read_csv_data(file_path, col_names=None, header=True, sep="\t", ignore_null=False):
 	data = list()
-	with open(file_path, "r") as f:
+	with open(file_path, "r", encoding='utf-8-sig') as f:
 		count = 0
 		for line in f.readlines():
 
@@ -38,6 +38,10 @@ def read_csv_data(file_path, col_names=None, header=True, sep="\t", ignore_null=
 
 
 def save_csv_data(data, file_path, col_names=None, exist_header=True):
+	if len(data) == 0:
+		log.info("\n\n\ndata is empty!!!!!\n\n\n")
+		return
+
 	with open(file_path, "w") as f:
 		if not col_names and data:
 			col_names = data[0].keys()
